<p align="center">
  <img src="https://github.com/UlionTse/lotterycn/blob/main/docs/lotterycn_logo.png"/>
</p>
<p align="center">
  <a href="https://pypi.org/project/lotterycn"><img alt="PyPI - Version" src="https://img.shields.io/pypi/v/lotterycn.svg"></a>
  <a href="https://anaconda.org/conda-forge/lotterycn"><img alt="Conda - Version" src="https://img.shields.io/conda/vn/conda-forge/lotterycn.svg"></a>
  <a href="https://pypi.org/project/lotterycn"><img alt="PyPI - License" src="https://img.shields.io/pypi/l/lotterycn.svg"></a>
  <a href="https://pypi.org/project/lotterycn"><img alt="PyPI - Python" src="https://img.shields.io/pypi/pyversions/lotterycn.svg"></a>
  <a href="https://pypi.org/project/lotterycn"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/lotterycn.svg"></a>
  <a href="https://pypi.org/project/lotterycn"><img alt="PyPI - Wheel" src="https://img.shields.io/badge/wheel-yes-brightgreen.svg"></a>
  <a href="https://pypi.org/project/lotterycn"><img alt="Downloads" src="https://pepy.tech/badge/lotterycn"></a>
</p>

* * *

**LotteryCN** is a library which aims to bring **enjoyable** analysis of lottery in Python.

- [Installation](#installation)
  - [From PyPI](#from-PyPI)
  - [From Conda](#from-Conda)
- [License](#License)

## Installation

### From PyPI

```shell
pip install --upgrde lotterycn
```

### From Conda

```shell
conda install -c conda-forge lotterycn
```